@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@ public:
 private:
 	void startElementHandler(const char *tag, const char **attributes);
 	void endElementHandler(const char *tag);
+	bool processNamespaces() const;
+	void namespaceListChangedHandler();
 
 	void generateTOC();
 
@@ -52,6 +54,8 @@ private:
 	BookReader myModelReader;
 	ReaderState myState;
 
+	std::string myOPFSchemePrefix;
+
 	std::string myFilePrefix;
 	std::map<std::string,std::string> myIdToHref;
 	std::vector<std::string> myHtmlFileNames;
